pitchtools.named_chromatic_pitch_tokens_to_named_chromatic_pitches
==================================================================

.. autofunction:: abjad.tools.pitchtools.named_chromatic_pitch_tokens_to_named_chromatic_pitches.named_chromatic_pitch_tokens_to_named_chromatic_pitches
